@@ -2,15 +2,15 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
+    http://sourceforge.net/projects/gpredict/
     More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+            http://gpredict.oz9aec.net/
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,12 +31,15 @@
 
 /** \brief Bit fields in the returned error code */
 enum {
-	FTC_ERROR_STEP_01 = 1 << 1,
-	FTC_ERROR_STEP_02 = 1 << 2,
-	FTC_ERROR_STEP_03 = 1 << 3,
-	FTC_ERROR_STEP_04 = 1 << 4,
-	FTC_ERROR_STEP_05 = 1 << 5,
-	FTC_ERROR_STEP_06 = 1 << 6
+    FTC_ERROR_STEP_01 = 1 << 1,
+    FTC_ERROR_STEP_02 = 1 << 2,
+    FTC_ERROR_STEP_03 = 1 << 3,
+    FTC_ERROR_STEP_04 = 1 << 4,
+    FTC_ERROR_STEP_05 = 1 << 5,
+    FTC_ERROR_STEP_06 = 1 << 6,
+    FTC_ERROR_STEP_07 = 1 << 7,
+    FTC_ERROR_STEP_08 = 1 << 8,
+    FTC_ERROR_STEP_09 = 1 << 9
 };
 
 guint first_time_check_run (void);
