@@ -2,15 +2,15 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-  Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <oz9aec@gmail.com>
 
   Comments, questions and bugreports should be submitted via
-  http://sourceforge.net/projects/groundstation/
+  http://sourceforge.net/projects/gpredict/
   More details can be found at the project home page:
 
-  http://groundstation.sourceforge.net/
+  http://gpredict.oz9aec.net/
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 #include "config-keys.h"
 #include "sat-cfg.h"
 #include "time-tools.h"
-#include "sat-popup-menu.h"
 #include "gtk-sat-data.h"
 #include "gpredict-utils.h"
 #include "gtk-azel-plot.h"
@@ -467,6 +466,9 @@ size_allocate_cb (GtkWidget *widget, GtkAllocation *allocation, gpointer data)
 		polv->width = allocation->width;
 		polv->height = allocation->height;
 
+        goo_canvas_set_bounds (GOO_CANVAS (GTK_AZEL_PLOT (polv)->canvas), 0, 0,
+                               polv->width, polv->height);
+        
 		/* update coordinate system */
 		polv->x0 = POLV_X_MARGIN;
 		polv->xmax = polv->width - POLV_X_MARGIN;
