@@ -2,15 +2,15 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
+    http://sourceforge.net/projects/gpredict/
     More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+            http://gpredict.oz9aec.net/
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,6 +41,8 @@
 #include "gtk-sat-module.h"
 #include "gtk-sat-module-tmg.h"
 #include "gtk-sat-module-popup.h"
+#include "gtk-rig-ctrl.h"
+#include "gtk-rot-ctrl.h"
 #include "config-keys.h"
 
 
@@ -53,9 +55,13 @@ static void docking_state_cb (GtkWidget *menuitem, gpointer data);
 static void screen_state_cb  (GtkWidget *menuitem, gpointer data);
 static void sky_at_glance_cb (GtkWidget *menuitem, gpointer data);
 static void tmgr_cb          (GtkWidget *menuitem, gpointer data);
+static void rigctrl_cb       (GtkWidget *menuitem, gpointer data);
+static void rotctrl_cb       (GtkWidget *menuitem, gpointer data);
 static void delete_cb        (GtkWidget *menuitem, gpointer data);
 static void close_cb         (GtkWidget *menuitem, gpointer data);
 static void name_changed     (GtkWidget *widget, gpointer data);
+static void destroy_rotctrl  (GtkWidget *window, gpointer data);
+static void destroy_rigctrl  (GtkWidget *window, gpointer data);
 static gint window_delete    (GtkWidget *widget, GdkEvent *event, gpointer data);
 
 
@@ -155,8 +161,29 @@ gtk_sat_module_popup (GtkSatModule *module)
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 	g_signal_connect (menuitem, "activate", G_CALLBACK (tmgr_cb), module);
+    
+    /* separator */
+    menuitem = gtk_separator_menu_item_new ();
+    gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 
-
+    /* Radio Control */
+    menuitem = gtk_image_menu_item_new_with_label (_("Radio Control"));
+    buff = icon_file_name ("gpredict-oscilloscope-small.png");
+    image = gtk_image_new_from_file (buff);
+    g_free (buff);
+    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+    gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+    g_signal_connect (menuitem, "activate", G_CALLBACK (rigctrl_cb), module);
+    
+    /* Antenna Control */
+    menuitem = gtk_image_menu_item_new_with_label (_("Antenna Control"));
+    buff = icon_file_name ("gpredict-antenna-small.png");
+    image = gtk_image_new_from_file (buff);
+    g_free (buff);
+    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+    gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+    g_signal_connect (menuitem, "activate", G_CALLBACK (rotctrl_cb), module);
+     
 	/* separator */
 	menuitem = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
@@ -219,7 +246,24 @@ gtk_sat_module_popup (GtkSatModule *module)
 static void
 config_cb        (GtkWidget *menuitem, gpointer data)
 {
-	gtk_sat_module_config_cb (menuitem, data);
+    GtkSatModule *module = GTK_SAT_MODULE (data);
+    
+    if (module->rigctrlwin || module->rotctrlwin) {
+        GtkWidget *dialog;
+        /* FIXME: should offer option to close controllers */
+        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+                                         GTK_MESSAGE_ERROR,
+                                         GTK_BUTTONS_OK,
+                                         _("A module can not be configured while the "\
+                                           "radio or rotator controller is active.\n\n"\
+                                           "Please close the radio and rotator controllers "\
+                                           "and try again."));
+        gtk_dialog_run (GTK_DIALOG (dialog));
+        gtk_widget_destroy (dialog);
+    }
+    else {
+	   gtk_sat_module_config_cb (menuitem, data);
+    }
 }
 
 
@@ -273,10 +317,10 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, entry,
 						  _("Enter a short name for this module.\n"\
-							"Allowed charachters: 0..9, a..z, A..Z, - and _"),
+							"Allowed characters: 0..9, a..z, A..Z, - and _"),
 						  _("The name will be used to identify the module "\
 							"and it is also used a file name for saving the data."\
-							"Max length is 25 charachters."));
+							"Max length is 25 characters."));
 
 	/* attach changed signal so that we can enable OK button when
 	   a proper name has been entered
@@ -316,15 +360,12 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 					 gtk_entry_get_text (GTK_ENTRY (entry)));
 
 		/* build full file names */
-		source = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-							  ".gpredict2", G_DIR_SEPARATOR_S,
-							  "modules", G_DIR_SEPARATOR_S,
-							  module->name, ".mod", NULL);
-		target = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-							  ".gpredict2", G_DIR_SEPARATOR_S,
-							  "modules", G_DIR_SEPARATOR_S,
-							  gtk_entry_get_text (GTK_ENTRY (entry)),
-							  ".mod", NULL);
+                gchar *moddir = get_modules_dir ();
+                source = g_strconcat (moddir, G_DIR_SEPARATOR_S,
+                                      module->name, ".mod", NULL);
+                target = g_strconcat (moddir, G_DIR_SEPARATOR_S,
+                                      gtk_entry_get_text (GTK_ENTRY (entry)), ".mod", NULL);
+                g_free (moddir);
 
 		/* copy file */
 		if (gpredict_file_copy (source, target)) {
@@ -333,9 +374,9 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 						 __FILE__, __LINE__, module->name);
 		}
 		else {
-			sat_log_log (SAT_LOG_LEVEL_MSG,
-						 _("%s:%d: Successfully cloned %s."),
-						 __FILE__, __LINE__, module->name);
+                        sat_log_log (SAT_LOG_LEVEL_MSG,
+                                     _("%s:%d: Successfully cloned %s."),
+                                     __FILE__, __LINE__, module->name);
 
 			/* open module if requested */
 			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggle))) {
@@ -612,7 +653,7 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 	default:
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-					 _("%s:%d: Unknown module satate: %d"),
+					 _("%s:%d: Unknown module state: %d"),
 					 __FILE__, __LINE__, GTK_SAT_MODULE (module)->state);
 		break;
 
@@ -755,7 +796,7 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 	default:
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-					 _("%s:%d: Unknown module satate: %d"),
+					 _("%s:%d: Unknown module state: %d"),
 					 __FILE__, __LINE__, GTK_SAT_MODULE (module)->state);
 		break;
 
@@ -797,7 +838,14 @@ sky_at_glance_cb (GtkWidget *menuitem, gpointer data)
 
 	/* create sky at a glance widget */
 	module->busy = TRUE;
-	skg = gtk_sky_glance_new (module->satellites, module->qth);
+    
+    if (sat_cfg_get_bool (SAT_CFG_BOOL_PRED_USE_REAL_T0)) {
+        skg = gtk_sky_glance_new (module->satellites, module->qth, 0.0);
+    }
+    else {
+        skg = gtk_sky_glance_new (module->satellites, module->qth, module->tmgCdnum);
+    }
+    
 	module->busy = FALSE;
 
 	gtk_container_set_border_width (GTK_CONTAINER (window), 10);
@@ -816,6 +864,161 @@ tmgr_cb          (GtkWidget *menuitem, gpointer data)
 	tmg_create (module);
 }
 
+/** \brief Open Radio control window. 
+ * \param menuitem The menuitem that was selected.
+ * \param data Pointer the GtkSatModule.
+ */
+static void
+rigctrl_cb          (GtkWidget *menuitem, gpointer data)
+{
+    GtkSatModule *module = GTK_SAT_MODULE (data);
+    gchar *buff;
+    
+    if (module->rigctrlwin != NULL) {
+        /* there is already a roto controller for this module */
+        gtk_window_present (GTK_WINDOW (module->rigctrlwin));
+        return;
+    }
+
+    module->rigctrl = gtk_rig_ctrl_new (module);
+    
+    if (module->rigctrl == NULL) {
+        /* gtk_rot_ctrl_new returned NULL becasue no radios are configured */
+        GtkWidget *dialog;
+        dialog = gtk_message_dialog_new (GTK_WINDOW (app),
+                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                         _("You have no radio configuration!\n"\
+                                           "Please configure a radio first.")
+                                        );
+        g_signal_connect_swapped (dialog, "response", 
+                                  G_CALLBACK (gtk_widget_destroy), dialog);
+        gtk_window_set_title (GTK_WINDOW (dialog), _("ERROR"));
+        gtk_widget_show_all (dialog);
+        
+        return;
+    }
+    
+    /* create a window */
+    module->rigctrlwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    buff = g_strdup_printf (_("Gpredict Radio Control: %s"), module->name);
+    gtk_window_set_title (GTK_WINDOW (module->rigctrlwin), buff);
+    g_free (buff);
+    g_signal_connect (G_OBJECT (module->rigctrlwin), "delete_event",
+                      G_CALLBACK (window_delete), NULL);
+    g_signal_connect (G_OBJECT (module->rigctrlwin), "destroy",
+                      G_CALLBACK (destroy_rigctrl), module);
+
+    /* window icon */
+    buff = icon_file_name ("gpredict-oscilloscope.png");
+    gtk_window_set_icon_from_file (GTK_WINDOW (module->rigctrlwin), buff, NULL);
+    g_free (buff);
+    
+    gtk_container_add (GTK_CONTAINER (module->rigctrlwin), module->rigctrl);
+    
+    gtk_widget_show_all (module->rigctrlwin);
+
+}
+
+
+/** \brief Destroy radio control window.
+ * \param window Pointer to the radio control window.
+ * \param data Pointer to the GtkSatModule to which this controller is attached.
+ * 
+ * This function is called automatically when the window is destroyed.
+ */
+static void
+destroy_rigctrl  (GtkWidget *window, gpointer data)
+{
+    GtkSatModule *module = GTK_SAT_MODULE (data);
+    
+    module->rigctrlwin = NULL;
+    module->rigctrl = NULL;
+}
+
+
+/** \brief Open antenna rotator control window. 
+ * \param menuitem The menuitem that was selected.
+ * \param data Pointer the GtkSatModule.
+ */
+static void
+rotctrl_cb          (GtkWidget *menuitem, gpointer data)
+{
+    GtkSatModule *module = GTK_SAT_MODULE (data);
+    gchar *buff;
+    
+    if (module->rotctrlwin != NULL) {
+        /* there is already a roto controller for this module */
+        gtk_window_present (GTK_WINDOW (module->rotctrlwin));
+        return;
+    }
+
+    module->rotctrl = gtk_rot_ctrl_new (module);
+    
+    if (module->rotctrl == NULL) {
+        /* gtk_rot_ctrl_new returned NULL becasue no rotators are configured */
+        GtkWidget *dialog;
+        dialog = gtk_message_dialog_new (GTK_WINDOW (app),
+                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                         _("You have no rotator configuration!\n"\
+                                           "Please configure an antenna rotator first.")
+                                        );
+        g_signal_connect_swapped (dialog, "response", 
+                                  G_CALLBACK (gtk_widget_destroy), dialog);
+        gtk_window_set_title (GTK_WINDOW (dialog), _("ERROR"));
+        gtk_widget_show_all (dialog);
+        
+        return;
+    }
+    
+    /* create a window */
+    module->rotctrlwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    buff = g_strdup_printf (_("Gpredict Rotator Control: %s"), module->name);
+    gtk_window_set_title (GTK_WINDOW (module->rotctrlwin), buff);
+    g_free (buff);
+    g_signal_connect (G_OBJECT (module->rotctrlwin), "delete_event",
+                      G_CALLBACK (window_delete), module);
+    g_signal_connect (G_OBJECT (module->rotctrlwin), "destroy",
+                      G_CALLBACK (destroy_rotctrl), module);
+
+    /* window icon */
+    buff = icon_file_name ("gpredict-antenna.png");
+    gtk_window_set_icon_from_file (GTK_WINDOW (module->rotctrlwin), buff, NULL);
+    g_free (buff);
+    
+    gtk_container_add (GTK_CONTAINER (module->rotctrlwin), module->rotctrl);
+    
+    gtk_widget_show_all (module->rotctrlwin);
+}
+
+
+/** \brief Destroy rotator control window.
+ * \param window Pointer to the rotator control window.
+ * \param data Pointer to the GtkSatModule to which this controller is attached.
+ * 
+ * This function is called automatically when the window is destroyed.
+ */
+static void
+destroy_rotctrl  (GtkWidget *window, gpointer data)
+{
+    GtkSatModule *module = GTK_SAT_MODULE (data);
+    
+    module->rotctrlwin = NULL;
+    module->rotctrl    = NULL;
+}
+
+/* ensure that deleted top-level windows are destroyed */
+static gint
+window_delete      (GtkWidget *widget,
+                    GdkEvent  *event,
+                    gpointer   data)
+{
+    return FALSE;
+}
+
+
+
 /** \brief Close module.
  *
  * This function is called when the user selects the close menu
@@ -840,13 +1043,12 @@ delete_cb         (GtkWidget *menuitem, gpointer data)
 {
 	gchar *file;
 	GtkWidget *dialog;
-	//GtkWidget *parent = gtk_widget_get_toplevel (GTK_WIDGET (data));
+        gchar *moddir;
 
-
-	file = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-						".gpredict2", G_DIR_SEPARATOR_S,
-						"modules", G_DIR_SEPARATOR_S,
-						GTK_SAT_MODULE (data)->name, ".mod", NULL);
+        moddir = get_modules_dir ();
+        file = g_strconcat (moddir, G_DIR_SEPARATOR_S,
+                            GTK_SAT_MODULE (data)->name, ".mod", NULL);
+        g_free (moddir);
 
 	gtk_sat_module_close_cb (menuitem, data);
 
@@ -948,16 +1150,6 @@ name_changed          (GtkWidget *widget, gpointer data)
 
 
 
-/* ensure that deleted top-level windows are destroyed */
-static gint
-window_delete      (GtkWidget *widget,
-					GdkEvent  *event,
-					gpointer   data)
-{
-	return FALSE;
-}
-
-
 
 /** \brief Snoop window position and size when main window receives configure event.
  *  \param widget Pointer to the module window.
