@@ -2,15 +2,15 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-  Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <oz9aec@gmail.com>
 
   Comments, questions and bugreports should be submitted via
-  http://sourceforge.net/projects/groundstation/
+  http://sourceforge.net/projects/gpredict/
   More details can be found at the project home page:
 
-  http://groundstation.sourceforge.net/
+  http://gpredict.oz9aec.net/
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -95,7 +95,7 @@ select_map (const gchar *curmap)
     
     /* select current map file */
     if (g_path_is_absolute (curmap)) {
-        /* map is user specific, ie. in $HOME/.gpredict2/maps/ */
+        /* map is user specific, ie. in USER_CONF_DIR/maps/ */
         selection = g_strdup (curmap);
     }
     else {
