@@ -2,15 +2,15 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
+    http://sourceforge.net/projects/gpredict/
     More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+            http://gpredict.oz9aec.net/
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 #include "sat-cfg.h"
 #include "gpredict-utils.h"
 #include "sat-pref-debug.h"
+#include "compat.h"
 
 
 #define SEC_PER_DAY 86400
@@ -65,6 +66,7 @@ GtkWidget *sat_pref_debug_create ()
 	GtkWidget   *label;
 	GtkWidget   *butbox;
 	gchar       *msg;
+    gchar       *confdir;
 
 
 	vbox = gtk_vbox_new (FALSE, 10);
@@ -121,17 +123,15 @@ GtkWidget *sat_pref_debug_create ()
 	gtk_box_pack_start (GTK_BOX (vbox), gtk_hseparator_new (), FALSE, FALSE, 0);
 
 	/* info label */
+    confdir = get_user_conf_dir ();
 	msg = g_strdup_printf (_("Gpredict stores all run-time messages "
-							 "in the %s%s.gpredict2%slogs%s folder. The "
+                             "in the %s%slogs%s folder. The "
 							 "current log file is called gpredict.log and the "
 							 "file is always kept until the next execution so "
 							 "that you can examine it in case of a failure. "
 							 "If old log files are kept, they are called "
 							 "gpredict-XYZ.log where XYZ is a uniques timestamp."),
-						   g_get_home_dir (),
-						   G_DIR_SEPARATOR_S,
-						   G_DIR_SEPARATOR_S,
-						   G_DIR_SEPARATOR_S);
+                           confdir, G_DIR_SEPARATOR_S, G_DIR_SEPARATOR_S);
 	label = gtk_label_new (msg);
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
