@@ -2,15 +2,15 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-  Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <oz9aec@gmail.com>
 
   Comments, questions and bugreports should be submitted via
-  http://sourceforge.net/projects/groundstation/
+  http://sourceforge.net/projects/gpredict/
   More details can be found at the project home page:
 
-  http://groundstation.sourceforge.net/
+  http://gpredict.oz9aec.net/
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -190,10 +190,10 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, name,
 						  _("Enter a short name for this ground station, e.g. callsign.\n"\
-							"Allowed charachters: 0..9, a..z, A..Z, - and _"),
+							"Allowed characters: 0..9, a..z, A..Z, - and _"),
 						  _("The name will be used to identify the ground station when "\
 							"it is presented to the user. Maximum allowed length "\
-							"is 25 charachters."));
+							"is 25 characters."));
 	gtk_table_attach_defaults (GTK_TABLE (table), name, 1, 4, 0, 1);
 
 	/* attach changed signal so that we can enable OK button when
