@@ -2,15 +2,15 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
+    http://sourceforge.net/projects/gpredict/
     More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+            http://gpredict.oz9aec.net/
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,6 +50,7 @@ static guint flags;
 static gboolean dirty = FALSE;
 static gboolean reset = FALSE;
 
+extern const gchar *SINGLE_SAT_FIELD_TITLE[];
 extern const gchar *SINGLE_SAT_FIELD_HINT[];
 
 static void toggle_cb  (GtkToggleButton *toggle, gpointer data);
@@ -100,7 +101,8 @@ GtkWidget *sat_pref_single_sat_create (GKeyFile *cfg)
 
 	for (i = 0; i < SINGLE_SAT_FIELD_NUMBER; i++) {
 
-		check[i] = gtk_check_button_new_with_label (SINGLE_SAT_FIELD_HINT[i]);
+        check[i] = gtk_check_button_new_with_label (SINGLE_SAT_FIELD_TITLE[i]);
+        gtk_widget_set_tooltip_text (check[i], SINGLE_SAT_FIELD_HINT[i]);
 
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check[i]),
 					      flags & (1 << i));
